/////////////////////////////////////////////////////////////////////////////
// Copyright (c) 2009-2014 Alan Wright. All rights reserved.
// Distributable under the terms of either the Apache License (Version 2.0)
// or the GNU Lesser General Public License.
/////////////////////////////////////////////////////////////////////////////

#include "LuceneInc.h"
#include "IndexDeletionPolicy.h"

namespace Lucene {

IndexDeletionPolicy::IndexDeletionPolicy() {
}

IndexDeletionPolicy::~IndexDeletionPolicy() {
}

}
